| apply_links | R Documentation |
This function applies the specified link functions in the list of links to the
formula or bmmformula that is passed to it. This function is mostly used internally for configuring
bmmodels.
apply_links(formula, links = nlist())
formula |
A |
links |
A list of |
The formula or bmmformula the links have been applied to
# specify a bmmformula
form <- bmf(x ~ a + c, kappa ~ 1, a ~ 1, c ~ 1)
links <- list(a = "log", c = "logit")
apply_links(form, links)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.