bmm-package: Easy and Accesible Bayesian Measurement Models Using 'brms'

bmm-packageR Documentation

Easy and Accesible Bayesian Measurement Models Using 'brms'

Description

logo

Fit computational and measurement models using full Bayesian inference. The package provides a simple and accessible interface by translating complex domain-specific models into 'brms' syntax, a powerful and flexible framework for fitting Bayesian regression models using 'Stan'. The package is designed so that users can easily apply state-of-the-art models in various research fields, and so that researchers can use it as a new model development framework. References: Frischkorn and Popov (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3758/s13428-025-02643-0")}.

Author(s)

Maintainer: Vencislav Popov vencislav.popov@gmail.com (ORCID) [copyright holder]

Authors:

Other contributors:

  • Chenyu Li [contributor]

  • Paul-Christian Bürkner paul.buerkner@gmail.com (Creator of 'brms', code portions of which are used in 'bmm'.) [copyright holder]

See Also

Useful links:


bmm documentation built on June 5, 2026, 9:07 a.m.