View source: R/helpers-inits.R
| create_initfun | R Documentation |
Called by bmm() to create an initfun for models that require initial values to properly start sampling
create_initfun(model, data, formula)
model |
The |
data |
The user supplied data.frame used to fit the model |
formula |
The |
An initfun with no arguments that generates inital values suitable for the STAN parameters generated by the respective model call
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.