| data_color_judgement_task | R Documentation |
Raw data from 50 subjects that completed a color judgement task. Participants
had to detect if there were more blue or red dots in a cloud of colored dots.
The task included a difficulty manipulation coded by the condition variable.
In the easy condition 60 percent of the dots were either blue or red, and in
the difficult condition 52 percent were either blue or red. In addition the
fixation cross preceding the onset of the dot matrix had a variable presentation
time coded in the fix_duration variable
data_color_judgement_task
data_color_judgement_taskA data frame with 9941 rows and 10 columns:
Character String uniquely identifying each subject
The trial number of the experimental trials
A character variable coding the difficulty condition
The duration in ms the fixation cross was shown before onset of the dot matrix.
The color / response that was more frequent in the dot matrix
The response coded in red / blue given by the participant
Boolean variable coding if the response was correct or not.
The reaction time in seconds.
The actual key pressed by the participants
The correct key that should have been pressed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.