parameters: Get parameter information for a bmm model

View source: R/helpers-parameters.R

parametersR Documentation

Get parameter information for a bmm model

Description

Returns a data frame with information about the model parameters, including their descriptions, whether they are fixed, their link functions, and optionally their default priors.

Usage

parameters(x, ...)

## S3 method for class 'bmmodel'
parameters(x, formula = NULL, ...)

## S3 method for class 'bmmfit'
parameters(x, ...)

Arguments

x

A bmmodel object (e.g., sdm(resp_error = "y")) or a bmmfit object (a fitted model returned by bmm).

...

Additional arguments (currently unused).

formula

An optional bmmformula object. Only relevant for M3 custom models, where additional parameters are discovered from the formula. Ignored for all other models.

Value

A data frame of class bmm_parameters with one row per parameter and columns: parameter, description, fixed, value, and link.

Examples

# For an unfitted model
parameters(sdm(resp_error = "y"))

# For an M3 model
parameters(m3(
  resp_cats = c("corr", "other", "npl"),
  num_options = c(1, 4, 5),
  version = "ss"
))

bmm documentation built on March 30, 2026, 5:08 p.m.