print_pretty_models_md: Generate a markdown list of the measurement models available...

View source: R/helpers-model.R

print_pretty_models_mdR Documentation

Description

Used internally to automatically populate information in the README file

Usage

print_pretty_models_md()

Value

Markdown code for printing the list of measurement models available in bmm

Examples

print_pretty_models_md()


bmm documentation built on March 30, 2026, 5:08 p.m.