View source: R/distributions.R
| rejection_sampling | R Documentation |
Performs rejection sampling to generate samples from a target distribution.
rejection_sampling(n, f, max_f, proposal_fun, ...)
n |
Integer. The number of samples to generate. |
f |
Function. The target density function from which to sample. |
max_f |
Numeric. The maximum value of the target density function |
proposal_fun |
Function. A function that generates samples from the proposal distribution. |
... |
Additional arguments to be passed to the target density function |
A numeric vector of length n containing samples from the target distribution.
target_density <- function(x) brms::dvon_mises(x, mu = 0, kappa = 10)
proposal <- function(n) runif(n, min = -pi, max = pi)
samples <- rejection_sampling(10000, target_density, max_f = target_density(0), proposal)
hist(samples, freq = FALSE)
curve(target_density, col = "red", add = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.