Given the model, the data and the formula for the model,
this function will return the combined stan data generated by bmm and
brms
Usage
# S3 method for bmmformula
standata(object, data, model, ...)
Value
A named list of objects containing the required data to fit a bmm
model with Stan.
Arguments
object
A bmmformula object
data
An object of class data.frame, containing data of all variables
used in the model. The names of the variables must match the variable names
passed to the bmmodel object for required argurments.
model
A description of the model to be fitted. This is a call to a
bmmodel such as mixture3p() function. Every model function has a
number of required arguments which need to be specified within the function
call. Call supported_models() to see the list of supported models and
their required arguments
...
Further arguments passed to brms::standata(). See the
description of brms::standata() for more details