supported_models: Measurement models available in 'bmm'

View source: R/helpers-model.R

supported_modelsR Documentation

Measurement models available in bmm

Description

Measurement models available in bmm

Usage

supported_models(print_call = TRUE)

Arguments

print_call

Logical; If TRUE (default), the function will print information about how each model function should be called and its required arguments. If FALSE, the function will return a character vector with the names of the available models

Value

A character vector of measurement models available in bmm

Examples

supported_models()

bmm documentation built on March 30, 2026, 5:08 p.m.