| ezdm_dist | R Documentation |
Density and random generation functions for the EZ-Diffusion Model. The model operates on aggregated data: mean reaction time, variance of reaction time, and number of responses to the upper boundary.
dezdm(
mean_rt,
var_rt,
n_upper,
n_trials,
drift,
bound,
ndt,
zr = 0.5,
s = 1,
version = c("3par", "4par"),
log = TRUE
)
rezdm(
n,
n_trials,
drift,
bound,
ndt,
zr = 0.5,
s = 1,
version = c("3par", "4par")
)
mean_rt |
Observed mean reaction time(s) in seconds. For version "3par", a numeric vector or single value. For version "4par", either a vector of length 2 (c(mean_rt_upper, mean_rt_lower)) for single observation, or a matrix with 2 columns for multiple observations. |
var_rt |
Observed variance of reaction times in seconds^2. For version "3par", a numeric vector or single value. For version "4par", either a vector of length 2 (c(var_rt_upper, var_rt_lower)) for single observation, or a matrix with 2 columns for multiple observations. |
n_upper |
Number of responses to the upper boundary |
n_trials |
Total number of trials |
drift |
Drift rate (evidence accumulation rate; can be positive or negative for below-chance performance). |
bound |
Boundary separation (distance between decision thresholds). |
ndt |
Non-decision time (seconds). |
zr |
Relative starting point (0 to 1). Only used for version "4par". |
s |
Diffusion constant (standard deviation of noise), default = 1. |
version |
Character; either "3par" (default) or "4par" |
log |
Logical; if |
n |
Number of samples to generate |
dezdm gives the log-density of the observed summary statistics
under the EZDM, and rezdm generates random summary statistics from the
implied sampling distributions.
Wagenmakers, E.-J., Van Der Maas, H. L. J., & Grasman, R. P. P. P. (2007). An EZ-diffusion model for response time and accuracy. Psychonomic Bulletin & Review, 14(1), 3-22.
Chávez De la Peña, A. F., & Vandekerckhove, J. (2025). An EZ Bayesian hierarchical drift diffusion model for response time and accuracy. Psychonomic Bulletin & Review.
# 3-parameter version (single observation)
dezdm(
mean_rt = 0.5, var_rt = 0.02, n_upper = 80, n_trials = 100,
drift = 2, bound = 1.5, ndt = 0.3
)
# 3-parameter version (vectorized)
dezdm(
mean_rt = c(0.5, 0.55), var_rt = c(0.02, 0.025),
n_upper = c(80, 75), n_trials = c(100, 100),
drift = 2, bound = 1.5, ndt = 0.3
)
# 4-parameter version (single observation)
dezdm(
mean_rt = c(0.45, 0.55), var_rt = c(0.018, 0.025),
n_upper = 80, n_trials = 100,
drift = 2, bound = 1.5, ndt = 0.3, zr = 0.55, version = "4par"
)
# generate random summary statistics
rezdm(n = 100, n_trials = 100, drift = 2, bound = 1.5, ndt = 0.3)
rezdm(
n = 100, n_trials = 100, drift = 2, bound = 1.5, ndt = 0.3,
zr = 0.55, version = "4par"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.