View source: R/helpers-parameters.R
| parameters | R Documentation |
Returns a data frame with information about the model parameters, including their descriptions, whether they are fixed, their link functions, and optionally their default priors.
parameters(x, ...)
## S3 method for class 'bmmodel'
parameters(x, formula = NULL, ...)
## S3 method for class 'bmmfit'
parameters(x, ...)
x |
A |
... |
Additional arguments (currently unused). |
formula |
An optional |
A data frame of class bmm_parameters with one row per
parameter and columns: parameter, description,
fixed, value, and link.
# For an unfitted model
parameters(sdm(resp_error = "y"))
# For an M3 model
parameters(m3(
resp_cats = c("corr", "other", "npl"),
num_options = c(1, 4, 5),
version = "ss"
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.